@@ -47,10 +47,13 @@ class Minitest::RetryTest < Minitest::Test
       end
       Minitest::Runnable.run_one_method(retry_test, :fail, self.reporter)
     end
+
+    failed_method_name = RUBY_VERSION >= "3.4" ? "'fail'" : "`fail'"
+    path = Gem::Version.new(Minitest::VERSION) >= Gem::Version.new("5.21.0") ? "test/minitest/retry_test.rb" : __FILE__
     expect = <<-EOS
-[MinitestRetry] retry 'fail' count: 1,  msg: RuntimeError: parsing error\n    #{__FILE__}:45:in `fail'
-[MinitestRetry] retry 'fail' count: 2,  msg: RuntimeError: parsing error\n    #{__FILE__}:45:in `fail'
-[MinitestRetry] retry 'fail' count: 3,  msg: RuntimeError: parsing error\n    #{__FILE__}:45:in `fail'
+[MinitestRetry] retry 'fail' count: 1,  msg: RuntimeError: parsing error\n    #{path}:45:in #{failed_method_name}
+[MinitestRetry] retry 'fail' count: 2,  msg: RuntimeError: parsing error\n    #{path}:45:in #{failed_method_name}
+[MinitestRetry] retry 'fail' count: 3,  msg: RuntimeError: parsing error\n    #{path}:45:in #{failed_method_name}
     EOS
 
     refute reporter.passed?
@@ -238,6 +241,122 @@ class Minitest::RetryTest < Minitest::Test
     end
   end
 
+  def test_retry_when_class_in_classes_to_retry
+    capture_stdout do
+      retry_test = Class.new(Minitest::Test) do
+        @@counter = 0
+
+        class << self
+          def name
+            'TestClass'
+          end
+        end
+
+        def self.counter
+          @@counter
+        end
+        Minitest::Retry.use! classes_to_retry: ["Minitest::Test"]
+        def fail
+          @@counter += 1
+          assert false, 'fail test'
+        end
+      end
+      Minitest::Runnable.run_one_method(retry_test, :fail, self.reporter)
+
+      assert_equal 4, retry_test.counter
+    end
+  end
+
+  def test_donot_retry_when_not_in_classes_to_retry
+    capture_stdout do
+      retry_test = Class.new(Minitest::Test) do
+        @@counter = 0
+
+        class << self
+          def name
+            'TestClass'
+          end
+        end
+
+        def self.counter
+          @@counter
+        end
+        Minitest::Retry.use! classes_to_retry: ["OtherClass"]
+        def another_fail
+          @@counter += 1
+          assert false, 'fail test'
+        end
+      end
+      Minitest::Runnable.run_one_method(retry_test, :another_fail, self.reporter)
+
+      assert_equal 1, retry_test.counter
+    end
+  end
+
+  def test_retry_when_method_in_methods_to_skip
+    capture_stdout do
+      retry_test = Class.new(Minitest::Test) do
+        @@counter = 0
+
+        class << self
+          def name
+            'TestClass'
+          end
+        end
+
+        def self.counter
+          @@counter
+        end
+        Minitest::Retry.use! methods_to_skip: ["TestClass#fail"]
+        def fail
+          @@counter += 1
+          assert false, 'fail test'
+        end
+      end
+      Minitest::Runnable.run_one_method(retry_test, :fail, self.reporter)
+
+      assert_equal 1, retry_test.counter
+    end
+  end
+
+  def test_retry_when_error_in_exceptions_to_skip
+    capture_stdout do
+      retry_test = Class.new(Minitest::Test) do
+        @@counter = 0
+        def self.counter
+          @@counter
+        end
+        Minitest::Retry.use! exceptions_to_skip: [TestError]
+        def raise_test_error
+          @@counter += 1
+          raise TestError, 'This does not trigger a retry.'
+        end
+      end
+      Minitest::Runnable.run_one_method(retry_test, :raise_test_error, self.reporter)
+
+      assert_equal 1, retry_test.counter
+    end
+  end
+
+  def test_retry_when_error_not_in_exceptions_to_skip
+    capture_stdout do
+      retry_test = Class.new(Minitest::Test) do
+        @@counter = 0
+        def self.counter
+          @@counter
+        end
+        Minitest::Retry.use! exceptions_to_skip: [TestError]
+        def raise_test_error
+          @@counter += 1
+          raise ArgumentError, 'This triggers a retry.'
+        end
+      end
+      Minitest::Runnable.run_one_method(retry_test, :raise_test_error, self.reporter)
+
+      assert_equal 4, retry_test.counter
+    end
+  end
+
   def test_run_failure_callback_on_failure
     on_failure_block_has_ran = false
     test_name, test_class, retry_test, result_in_callback = nil
